@@ -230,13 +230,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 		fprintf(stderr, "引数が正しくありません\n");
 		exit(EXIT_FAILURE);
 	}
-/*
-	else if(oparg->CHECK == NOT)
-	{
-		fprintf(stderr, "コンペアオプションが無効になっています\n");
-		exit(EXIT_FAILURE);
-	}
-*/
+
 	oparg->argc = argc;
 	oparg->src_index = optind;
 	oparg->dst_index = argc - 1;
@@ -246,10 +240,12 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	{
 		off_t index_tmp = oparg->dst_index;
 		off_t count_tmp = 0;
+
 		for(int tmp = optind; tmp < index_tmp; tmp++)
 		{
 			count_tmp++;
 		}
+
 		oparg->arg_count = count_tmp;
 	}
 
