@@ -1,7 +1,7 @@
 #ifndef DO_COMPARE_VERIFY_ONE_H
 #define DO_COMPARE_VERIFY_ONE_H
 
-#include "print_error.h"	// inline
+#include "print_error.h"
 #include "remove_source_unlink.h"
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
