@@ -13,11 +13,11 @@
 #include <sys/stat.h>
 
 /* 関数プロトタイプ */
-static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success);
+static void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success);
 static inline void set_today(char *today);
 static inline void set_time_now(char *hms);
 
-static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success)
+static void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success)
 {
 	/* ログを保存するフォルダが存在しない場合は作成する */
 	if(g_file_test(sdir->config_dir, G_FILE_TEST_EXISTS) == FALSE)
